@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -39,14 +39,14 @@ PageChoosePrinters::PageChoosePrinters(const QVariantHash &args, QWidget *parent
     setWindowTitle(i18nc("@title:window", "Select a Printer to Add"));
     // loads the standard key icon
     QPixmap pixmap;
-    pixmap = KIconLoader::global()->loadIcon("printer",
+    pixmap = KIconLoader::global()->loadIcon(QLatin1String("printer"),
                                              KIconLoader::NoGroup,
                                              KIconLoader::SizeEnormous, // a not so huge icon
                                              KIconLoader::DefaultState);
     QPixmap icon(pixmap);
     QPainter painter(&icon);
 
-    pixmap = KIconLoader::global()->loadIcon("preferences-other",
+    pixmap = KIconLoader::global()->loadIcon(QLatin1String("preferences-other"),
                                              KIconLoader::NoGroup,
                                              KIconLoader::SizeLarge, // a not so huge icon
                                              KIconLoader::DefaultState);
@@ -59,8 +59,8 @@ PageChoosePrinters::PageChoosePrinters(const QVariantHash &args, QWidget *parent
     painter.drawPixmap(startPoint, pixmap);
     ui->printerL->setPixmap(icon);
 
-    connect(ui->membersLV, SIGNAL(changed(bool)),
-            this, SIGNAL(allowProceed(bool)));
+    connect(ui->membersLV, static_cast<void (ClassListWidget::*) (bool)>(&ClassListWidget::changed),
+            this, &PageChoosePrinters::allowProceed);
 
     if (!args.isEmpty()) {
         setValues(args);
@@ -90,3 +90,5 @@ bool PageChoosePrinters::canProceed() const
 {
     return ui->membersLV->selectedPrinters().count() > 0;
 }
+
+#include "moc_PageChoosePrinters.cpp"
