@@ -144,9 +144,9 @@ public:
      * If you don't have any special reason for creating a connection
      * on your own consider calling global()
      */
-    explicit KCupsConnection(QObject *parent = 0);
-    explicit KCupsConnection(const QUrl &server, QObject *parent = 0);
-    ~KCupsConnection();
+    explicit KCupsConnection(QObject *parent = nullptr);
+    explicit KCupsConnection(const QUrl &server, QObject *parent = nullptr);
+    ~KCupsConnection() override;
 
     void setPasswordMainWindow(WId mainwindow);
 
@@ -362,7 +362,7 @@ Q_SIGNALS:
 protected:
     friend class KCupsRequest;
 
-    virtual void run() Q_DECL_OVERRIDE;
+    virtual void run() override;
     bool readyToStart();
     bool retry(const char *resource, int operation) const;
     ReturnArguments request(const KIppRequest &request, ipp_tag_t groupTag = IPP_TAG_ZERO) const;
@@ -373,8 +373,8 @@ private slots:
     void cancelDBusSubscription();
 
 protected:
-    virtual void connectNotify(const QMetaMethod & signal) Q_DECL_OVERRIDE;
-    virtual void disconnectNotify(const QMetaMethod & signal) Q_DECL_OVERRIDE;
+    virtual void connectNotify(const QMetaMethod & signal) override;
+    virtual void disconnectNotify(const QMetaMethod & signal) override;
     QString eventForSignal(const QMetaMethod & signal) const;
 
 private:
